==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2beta1HorizontalPodAutoscalerSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V2beta1HorizontalPodAutoscalerSpecFluent<A extends V2beta1HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A>{


    public Integer getMaxReplicas();
    public A withMaxReplicas(Integer maxReplicas);
    public Boolean hasMaxReplicas();
    public A withNewMaxReplicas(int arg1);
    public A withNewMaxReplicas(String arg1);
    public A addToMetrics(int index,V2beta1MetricSpec item);
    public A setToMetrics(int index,V2beta1MetricSpec item);
    public A addToMetrics(V2beta1MetricSpec... items);
    public A addAllToMetrics(Collection<V2beta1MetricSpec> items);
    public A removeFromMetrics(V2beta1MetricSpec... items);
    public A removeAllFromMetrics(Collection<V2beta1MetricSpec> items);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta1MetricSpec> getMetrics();
    public List<V2beta1MetricSpec> buildMetrics();
    public V2beta1MetricSpec buildMetric(int index);
    public V2beta1MetricSpec buildFirstMetric();
    public V2beta1MetricSpec buildLastMetric();
    public V2beta1MetricSpec buildMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricSpecBuilder> predicate);
    public A withMetrics(List<V2beta1MetricSpec> metrics);
    public A withMetrics(V2beta1MetricSpec... metrics);
    public Boolean hasMetrics();
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetric();
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetricLike(V2beta1MetricSpec item);
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> setNewMetricLike(int index,V2beta1MetricSpec item);
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMetric(int index);
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editFirstMetric();
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editLastMetric();
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricSpecBuilder> predicate);
    public Integer getMinReplicas();
    public A withMinReplicas(Integer minReplicas);
    public Boolean hasMinReplicas();
    public A withNewMinReplicas(int arg1);
    public A withNewMinReplicas(String arg1);
    
/**
 * This method has been deprecated, please use method buildScaleTargetRef instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1CrossVersionObjectReference getScaleTargetRef();
    public V2beta1CrossVersionObjectReference buildScaleTargetRef();
    public A withScaleTargetRef(V2beta1CrossVersionObjectReference scaleTargetRef);
    public Boolean hasScaleTargetRef();
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(V2beta1CrossVersionObjectReference item);
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(V2beta1CrossVersionObjectReference item);

    public interface MetricsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1MetricSpecFluent<V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<N>>{

        
    public N and();    public N endMetric();
}
    public interface ScaleTargetRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1CrossVersionObjectReferenceFluent<V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>>{

        
    public N and();    public N endScaleTargetRef();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta1HorizontalPodAutoscalerSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V2beta1HorizontalPodAutoscalerSpecFluent<A extends V2beta1HorizontalPodAutoscalerSpecFluent<A>> extends Fluent<A>{


    public Integer getMaxReplicas();
    public A withMaxReplicas(Integer maxReplicas);
    public Boolean hasMaxReplicas();
    public A addToMetrics(int index,V2beta1MetricSpec item);
    public A setToMetrics(int index,V2beta1MetricSpec item);
    public A addToMetrics(V2beta1MetricSpec... items);
    public A addAllToMetrics(Collection<V2beta1MetricSpec> items);
    public A removeFromMetrics(V2beta1MetricSpec... items);
    public A removeAllFromMetrics(Collection<V2beta1MetricSpec> items);
    
/**
 * This method has been deprecated, please use method buildMetrics instead.
 * @return The buildable object.
 */
@Deprecated public List<V2beta1MetricSpec> getMetrics();
    public List<V2beta1MetricSpec> buildMetrics();
    public V2beta1MetricSpec buildMetric(int index);
    public V2beta1MetricSpec buildFirstMetric();
    public V2beta1MetricSpec buildLastMetric();
    public V2beta1MetricSpec buildMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricSpecBuilder> predicate);
    public Boolean hasMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricSpecBuilder> predicate);
    public A withMetrics(List<V2beta1MetricSpec> metrics);
    public A withMetrics(V2beta1MetricSpec... metrics);
    public Boolean hasMetrics();
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetric();
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> addNewMetricLike(V2beta1MetricSpec item);
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> setNewMetricLike(int index,V2beta1MetricSpec item);
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMetric(int index);
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editFirstMetric();
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editLastMetric();
    public V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<A> editMatchingMetric(io.kubernetes.client.fluent.Predicate<V2beta1MetricSpecBuilder> predicate);
    public Integer getMinReplicas();
    public A withMinReplicas(Integer minReplicas);
    public Boolean hasMinReplicas();
    
/**
 * This method has been deprecated, please use method buildScaleTargetRef instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1CrossVersionObjectReference getScaleTargetRef();
    public V2beta1CrossVersionObjectReference buildScaleTargetRef();
    public A withScaleTargetRef(V2beta1CrossVersionObjectReference scaleTargetRef);
    public Boolean hasScaleTargetRef();
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRef();
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> withNewScaleTargetRefLike(V2beta1CrossVersionObjectReference item);
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editScaleTargetRef();
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRef();
    public V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<A> editOrNewScaleTargetRefLike(V2beta1CrossVersionObjectReference item);

    public interface MetricsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1MetricSpecFluent<V2beta1HorizontalPodAutoscalerSpecFluent.MetricsNested<N>>{

        
    public N and();    public N endMetric();
}
    public interface ScaleTargetRefNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1CrossVersionObjectReferenceFluent<V2beta1HorizontalPodAutoscalerSpecFluent.ScaleTargetRefNested<N>>{

        
    public N and();    public N endScaleTargetRef();
}


}
